"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const medianote_format_sdk_1 = require("medianote-format-sdk");
const medianote_entities_1 = require("medianote-entities");
const selectors_1 = require("./selectors");
class Format extends medianote_format_sdk_1.MedianoteFormat {
    constructor(api) {
        super(api, "Guardaserie", ["guardaserieId"]);
    }
    run(params) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.api.loadURL("https://www.guardaserie.tube/" + params.guardaserieId + "/");
            yield this.api.waitSelector(selectors_1.TITLE_SELECTOR);
            const title = this.api.getTextContent(selectors_1.TITLE_SELECTOR, true);
            const plot = { it: this.api.getTextContent(selectors_1.PLOT_SELECTOR, true) };
            const originalTitle = this.api
                .getTextContent(selectors_1.ORIGINAL_TITLE_SELECTOR, true)
                .replace("TITOLO ORIGINALE:", "")
                .trim();
            const genre = this.api
                .getTextContent(selectors_1.GENRE_SELECTOR, true)
                .replace("GENERE:", "")
                .trim();
            const genres = { [genre]: true };
            const poster = this.api.getSrc(selectors_1.POSTER_SELECTOR);
            const fanart = this.api.getSrc(selectors_1.FANART_SELECTOR);
            const year = this.api
                .getTextContent(selectors_1.YEAR_SELECTOR, true)
                .replace("ANNO:", "")
                .trim();
            const array = year.split("-");
            const releaseDate = new medianote_entities_1.PartialDate({ year: parseInt(array[0].trim()) });
            const terminationDate = array[1].trim() !== "In Lavorazione" ? null : new medianote_entities_1.PartialDate({ year: parseInt(array[1].trim()) });
            const seasons = {};
            const totalSeasons = this.api.querySelector(selectors_1.SEASONS_SELECTOR).children().length;
            const $ = this.api.get$();
            for (let seasonNumber = 1; seasonNumber <= totalSeasons; seasonNumber++) {
                const selector = "div.row-stagione-" + seasonNumber;
                const seasonNode = $(selector);
                const episodesArray = seasonNode.find(".col-xs-6.col-sm-3").toArray();
                let episodeNumber = 0;
                const episodes = {};
                for (const node of episodesArray) {
                    episodeNumber++;
                    const episodeNode = $(node);
                    const previewNode = episodeNode.find("div.content-image-screen img");
                    let preview = previewNode.attr("data-original");
                    if (preview === undefined || preview.length === 0)
                        preview = previewNode.attr("meta-src");
                    if (preview === undefined || preview.length === 0)
                        preview = previewNode.attr("src");
                    const episodeTitle = episodeNode
                        .find("div.upper-title-thumb span")
                        .text()
                        .trim();
                    const episodePlot = {
                        it: episodeNode
                            .find("div.title-serie-thumb-single p")
                            .text()
                            .trim()
                    };
                    const links = episodeNode.find("a > span");
                    const providers = ["speedvideo", "mixdrop", "gounlimited", "supervideo", "vup"];
                    const urls = {};
                    for (let i = 1; i <= 5; i++) {
                        const id = i != 1 ? i.toString() : "";
                        const embed = links.attr("meta-embed" + id);
                        if (embed !== "")
                            urls[providers[i - 1]] = embed;
                    }
                    const episode = new medianote_entities_1.Episode({
                        number: episodeNumber,
                        season: seasonNumber,
                        title: episodeTitle,
                        plot: episodePlot,
                        preview,
                        urls
                    });
                    episodes[episodeNumber] = episode;
                }
                seasons[seasonNumber] = episodes;
            }
            const serieObj = {
                title,
                originalTitle,
                plot,
                poster,
                fanart,
                releaseDate,
                genres,
                seasons,
                type: medianote_entities_1.MediaType.SERIE,
                extra: { guardaserieId: params.guardaserieId }
            };
            if (terminationDate)
                serieObj.terminationDate = terminationDate;
            return new medianote_entities_1.Serie(serieObj);
        });
    }
}
exports.Format = Format;
//# sourceMappingURL=index.js.map